@@ -3,7 +3,6 @@ from pathlib import Path
 
 import numpy as np
 from rich.progress import Progress
-from ruamel.yaml import YAML
 import cv2
 import mediapipe as mp
 
@@ -25,7 +24,11 @@ def runMediaPipe(session, dummyRun=False):
     mediaPipe_imgPathList_yaml = []
     mediaPipe_jsonPathList_yaml = []
 
-    with mp_holistic.Holistic() as holistic:
+    with mp_holistic.Holistic(
+                            static_image_mode = False, #use 'static image mode' to avoid system getting 'stuck' on ghost skeletons?
+                            model_complexity = 2, #in this house, we turn the Speed/Accuracy dial all the way towards accuracy \o/)
+                            ) as holistic:
+
         eachCamerasData = []  # Create an empty list that holds each cameras data
         for (
             thisVidPath
@@ -73,8 +76,8 @@ def runMediaPipe(session, dummyRun=False):
                             image_height, image_width, _ = image.shape
 
                             results = holistic.process(
-                                cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
-                            )  # THIS IS WHERE THE MAGIC HAPENS (ps. Convert the BGR image to RGB before processing.)
+                                cv2.cvtColor(image, cv2.COLOR_BGR2RGB), #Convert the BGR image to RGB before processing
+                            )  # NOTE: THIS IS WHERE THE MAGIC HAPENS 
 
                             try:
                                 results.pose_landmarks.landmark
@@ -293,15 +296,13 @@ def parseMediaPipe(session):
             mediaPipeData_nCams_nFrames_nImgPts_XYC[camNum, frNum, :, 1] = thisFrame_Y
             mediaPipeData_nCams_nFrames_nImgPts_XYC[camNum, frNum, :, 2] = thisFrame_C
 
+
     # convert from normalized screen coordinates to pixel coordinates
     mediaPipeData_nCams_nFrames_nImgPts_XYC[:, :, :, 0] *= session.image_width
     mediaPipeData_nCams_nFrames_nImgPts_XYC[:, :, :, 1] *= session.image_height
     mediaPipeData_nCams_nFrames_nImgPts_XYC[:, :, 34:, 2] = 1
 
-    np.save(
-        session.dataArrayPath / "mediaPipe_2d.npy",
-        mediaPipeData_nCams_nFrames_nImgPts_XYC,
-    )
+    np.save(session.dataArrayPath / "mediaPipeData_2d.npy", mediaPipeData_nCams_nFrames_nImgPts_XYC,)
 
     return mediaPipeData_nCams_nFrames_nImgPts_XYC
     
